@@ -1,16 +1,25 @@
 /*
- * "$Id: textcommon.c 8103 2008-11-06 00:53:01Z mike $"
+ * "$Id: textcommon.c,v 1.1.1.15 2005/01/04 19:16:03 jlovell Exp $"
  *
  *   Common text filter routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007-2008 by Apple Inc.
- *   Copyright 1997-2007 by Easy Software Products.
+ *   Copyright 1997-2005 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
- *   property of Apple Inc. and are protected by Federal copyright
- *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- *   which should have been included with this file.  If this file is
- *   file is missing or damaged, see the license at "http://www.cups.org/".
+ *   property of Easy Software Products and are protected by Federal
+ *   copyright law.  Distribution and use rights are outlined in the file
+ *   "LICENSE.txt" which should have been included with this file.  If this
+ *   file is missing or damaged please contact Easy Software Products
+ *   at:
+ *
+ *       Attn: CUPS Licensing Information
+ *       Easy Software Products
+ *       44141 Airport View Drive, Suite 204
+ *       Hollywood, Maryland 20636 USA
+ *
+ *       Voice: (301) 373-9600
+ *       EMail: cups-info@cups.org
+ *         WWW: http://www.cups.org
  *
  *   This file is subject to the Apple OS-Developed Software exception.
  *
@@ -26,7 +35,6 @@
  */
 
 #include "textcommon.h"
-#include <cups/i18n.h>
 
 
 /*
@@ -45,6 +53,7 @@ lchar_t	**Page = NULL;		/* Page characters */
 int	NumPages = 0;		/* Number of pages in document */
 float	CharsPerInch = 10;	/* Number of character columns per inch */
 float	LinesPerInch = 6;	/* Number of lines per inch */
+int	UTF8 = 0;		/* Use UTF-8 encoding? */
 int	NumKeywords = 0;	/* Number of known keywords */
 char	**Keywords = NULL;	/* List of known keywords */
 
@@ -514,9 +523,8 @@ TextMain(const char *name,	/* I - Name of filter */
 
   if (argc < 6 || argc > 7)
   {
-    _cupsLangPrintf(stderr,
-                    _("Usage: %s job-id user title copies options [file]\n"),
-                    name);
+    fprintf(stderr, "ERROR: %s job-id user title copies options [file]\n",
+            name);
     return (1);
   }
 
@@ -535,7 +543,7 @@ TextMain(const char *name,	/* I - Name of filter */
 
     if ((fp = fopen(argv[6], "rb")) == NULL)
     {
-      perror("DEBUG: unable to open print file - ");
+      perror("ERROR: unable to open print file - ");
       return (1);
     }
   }
@@ -560,9 +568,9 @@ TextMain(const char *name,	/* I - Name of filter */
 
     if ((val = getenv("CONTENT_TYPE")) == NULL)
     {
-      PrettyPrint = PRETTY_PLAIN;
-      NumKeywords = 0;
-      Keywords    = NULL;
+      PrettyPrint = PRETTY_CODE;
+      NumKeywords = sizeof(code_keywords) / sizeof(code_keywords[0]);
+      Keywords    = code_keywords;
     }
     else if (strcasecmp(val, "application/x-cshell") == 0)
     {
@@ -570,12 +578,6 @@ TextMain(const char *name,	/* I - Name of filter */
       NumKeywords = sizeof(csh_keywords) / sizeof(csh_keywords[0]);
       Keywords    = csh_keywords;
     }
-    else if (strcasecmp(val, "application/x-csource") == 0)
-    {
-      PrettyPrint = PRETTY_CODE;
-      NumKeywords = sizeof(code_keywords) / sizeof(code_keywords[0]);
-      Keywords    = code_keywords;
-    }
     else if (strcasecmp(val, "application/x-perl") == 0)
     {
       PrettyPrint = PRETTY_PERL;
@@ -590,9 +592,9 @@ TextMain(const char *name,	/* I - Name of filter */
     }
     else
     {
-      PrettyPrint = PRETTY_PLAIN;
-      NumKeywords = 0;
-      Keywords    = NULL;
+      PrettyPrint = PRETTY_CODE;
+      NumKeywords = sizeof(code_keywords) / sizeof(code_keywords[0]);
+      Keywords    = code_keywords;
     }
   }
 
@@ -605,38 +607,14 @@ TextMain(const char *name,	/* I - Name of filter */
                 !strcasecmp(val, "yes");
 
   if ((val = cupsGetOption("columns", num_options, options)) != NULL)
-  {
     PageColumns = atoi(val);
 
-    if (PageColumns < 1)
-    {
-      _cupsLangPrintf(stderr, _("ERROR: Bad columns value %d!\n"), PageColumns);
-      return (1);
-    }
-  }
-
   if ((val = cupsGetOption("cpi", num_options, options)) != NULL)
-  {
     CharsPerInch = atof(val);
 
-    if (CharsPerInch <= 0.0)
-    {
-      _cupsLangPrintf(stderr, _("ERROR: Bad cpi value %f!\n"), CharsPerInch);
-      return (1);
-    }
-  }
-
   if ((val = cupsGetOption("lpi", num_options, options)) != NULL)
-  {
     LinesPerInch = atof(val);
 
-    if (LinesPerInch <= 0.0)
-    {
-      _cupsLangPrintf(stderr, _("ERROR: Bad lpi value %f!\n"), LinesPerInch);
-      return (1);
-    }
-  }
-
   if (PrettyPrint)
     PageTop -= 216.0f / LinesPerInch;
 
@@ -729,8 +707,6 @@ TextMain(const char *name,	/* I - Name of filter */
           }
 
 	  keycol = column;
-
-          attr &= ~ATTR_BOLD;
           break;
 
       case 0x0d :		/* CR */
@@ -898,14 +874,14 @@ TextMain(const char *name,	/* I - Name of filter */
           if (ch < ' ')
             break;		/* Ignore other control chars */
 
-          if (PrettyPrint > PRETTY_PLAIN)
+          if (PrettyPrint)
 	  {
 	   /*
 	    * Do highlighting of C/C++ keywords, preprocessor commands,
 	    * and comments...
 	    */
 
-	    if (ch == ' ' && (attr & ATTR_BOLD))
+	    if ((ch == ' ' || ch == '\t') && (attr & ATTR_BOLD))
 	    {
 	     /*
 	      * Stop bolding preprocessor command...
@@ -958,7 +934,7 @@ TextMain(const char *name,	/* I - Name of filter */
 	      */
 
 	      cstring = -1;
-              attr    = ATTR_BLUE;
+              attr    |= ATTR_BLUE;
 	    }
             else if (ch == '*' && lastch == '/' && !cstring &&
 	             PrettyPrint != PRETTY_SHELL)
@@ -968,7 +944,7 @@ TextMain(const char *name,	/* I - Name of filter */
 	      */
 
 	      ccomment = 1;
-	      attr     = ATTR_ITALIC | ATTR_GREEN;
+	      attr     |= ATTR_ITALIC | ATTR_GREEN;
 	    }
 	    else if (ch == '/' && lastch == '/' && !cstring &&
 	             PrettyPrint == PRETTY_CODE)
@@ -977,7 +953,7 @@ TextMain(const char *name,	/* I - Name of filter */
 	      * Start a C++-style comment...
 	      */
 
-	      attr = ATTR_ITALIC | ATTR_GREEN;
+	      attr |= ATTR_ITALIC | ATTR_GREEN;
 	    }
 	    else if (ch == '#' && !cstring && PrettyPrint != PRETTY_CODE)
 	    {
@@ -985,7 +961,7 @@ TextMain(const char *name,	/* I - Name of filter */
 	      * Start a shell-style comment...
 	      */
 
-	      attr = ATTR_ITALIC | ATTR_GREEN;
+	      attr |= ATTR_ITALIC | ATTR_GREEN;
 	    }
 	    else if (ch == '#' && column == 0 && !ccomment && !cstring &&
 	             PrettyPrint == PRETTY_CODE)
@@ -994,7 +970,7 @@ TextMain(const char *name,	/* I - Name of filter */
 	      * Start a preprocessor command...
 	      */
 
-	      attr = ATTR_BOLD | ATTR_RED;
+	      attr |= ATTR_BOLD | ATTR_RED;
 	    }
           }
 
@@ -1166,7 +1142,7 @@ getutf8(FILE *fp)	/* I - File to read from */
   if ((ch = getc(fp)) == EOF)
     return (EOF);
 
-  if (ch < 0xc0)			/* One byte character? */
+  if (ch < 0xc0 || !UTF8)	/* One byte character? */
     return (ch);
   else if ((ch & 0xe0) == 0xc0)
   {
@@ -1207,5 +1183,5 @@ getutf8(FILE *fp)	/* I - File to read from */
 
 
 /*
- * End of "$Id: textcommon.c 8103 2008-11-06 00:53:01Z mike $".
+ * End of "$Id: textcommon.c,v 1.1.1.15 2005/01/04 19:16:03 jlovell Exp $".
  */
