@@ -1,5 +1,5 @@
 /*
- * "$Id: job.c,v 1.55 2005/03/04 01:20:00 jlovell Exp $"
+ * "$Id: job.c,v 1.55.2.3 2005/12/09 23:11:51 jlovell Exp $"
  *
  *   Job management routines for the Common UNIX Printing System (CUPS).
  *
@@ -175,20 +175,6 @@ CancelJob(int id,		/* I - Job to cancel */
 
       set_time(current, "time-at-completed");
 
-      if (current->procs)
-      {
-        free(current->procs);
-        current->procs = NULL;
-      }
-
-      if (current->filters)
-      {
-        for (i = 0; current->filters[i]; i++)
-          free(current->filters[i]);
-        free(current->filters);
-        current->filters = NULL;
-      }
-
      /*
       * Remove the print file for good if we aren't preserving jobs or
       * files...
@@ -1341,6 +1327,19 @@ StartJob(int       id,			/* I - Job ID */
     num_filters ++;
   }
 
+ /*
+  * Update the printer and job state to "processing"...
+  */
+
+  current->state->values[0].integer = IPP_JOB_PROCESSING;
+  current->status  = 0;
+  current->printer = printer;
+  printer->job     = current;
+  SetPrinterState(printer, IPP_PRINTER_PROCESSING, 0);
+
+  if (current->current_file == 0)
+    set_time(current, "time-at-processing");
+
  /*
   * Allocate space for filter & backend process IDs...
   */
@@ -1371,19 +1370,6 @@ StartJob(int       id,			/* I - Job ID */
     return;
   }
 
- /*
-  * Update the printer and job state to "processing"...
-  */
-
-  current->state->values[0].integer = IPP_JOB_PROCESSING;
-  current->status  = 0;
-  current->printer = printer;
-  printer->job     = current;
-  SetPrinterState(printer, IPP_PRINTER_PROCESSING, 0);
-
-  if (current->current_file == 0)
-    set_time(current, "time-at-processing");
-
  /*
   * Determine if we are printing a banner page or not...
   */
@@ -2009,7 +1995,10 @@ StartJob(int       id,			/* I - Job ID */
   }
 
   if (filters != NULL)
+  {
     free(filters);
+    filters = NULL;
+  }
 
  /*
   * Finally, pipe the final output into a backend process if needed...
@@ -2055,10 +2044,6 @@ StartJob(int       id,			/* I - Job ID */
                "Unable to open \"/dev/null\" - %s.", strerror(errno));
 
       AddPrinterHistory(printer);
-
-      if (filters != NULL)
-	free(filters);
-
       CancelJob(current->id, 0);
       return;
     }
@@ -2087,9 +2072,6 @@ StartJob(int       id,			/* I - Job ID */
 
       AddPrinterHistory(printer);
 
-      if (filters != NULL)
-        free(filters);
-
       cupsdClosePipe(statusfds);
       cupsdClosePipe(filterfds[slot]);
       CancelJob(current->id, 0);
@@ -2180,12 +2162,26 @@ StopJob(int id,			/* I - Job ID */
 
 	current->current_file --;
 
-        for (i = 0; current->procs[i]; i ++)
-	  if (current->procs[i] > 0)
-	  {
-	    kill(current->procs[i], force ? SIGKILL : SIGTERM);
-	    current->procs[i] = 0;
-	  }
+	if (current->procs)
+	{
+	  for (i = 0; current->procs[i]; i ++)
+	    if (current->procs[i] > 0)
+	    {
+	      kill(current->procs[i], force ? SIGKILL : SIGTERM);
+	      current->procs[i] = 0;
+	    }
+  
+	  free(current->procs);
+	  current->procs = NULL;
+	}
+
+	if (current->filters)
+	{
+	  for (i = 0; current->filters[i]; i++)
+	    free(current->filters[i]);
+	  free(current->filters);
+	  current->filters = NULL;
+	}
 
         if (current->pipe >= 0)
         {
@@ -2197,6 +2193,7 @@ StopJob(int id,			/* I - Job ID */
 	             current->pipe);
 
           close(current->pipe);
+	  FD_CLR(current->pipe, InputFds);
 	  FD_CLR(current->pipe, InputSet);
 	  current->pipe = -1;
         }
@@ -2457,6 +2454,7 @@ UpdateJob(job_t *job)		/* I - Job to check */
                  job->pipe);
 
       close(job->pipe);
+      FD_CLR(job->pipe, InputFds);
       FD_CLR(job->pipe, InputSet);
       job->pipe = -1;
     }
@@ -3171,5 +3169,5 @@ remove_unused_attrs(job_t *job)			/* I - Job attributes */
 
 
 /*
- * End of "$Id: job.c,v 1.55 2005/03/04 01:20:00 jlovell Exp $".
+ * End of "$Id: job.c,v 1.55.2.3 2005/12/09 23:11:51 jlovell Exp $".
  */
