@@ -1,5 +1,5 @@
 /*
- * "$Id: server.c,v 1.13 2005/01/06 01:26:12 jlovell Exp $"
+ * "$Id: server.c,v 1.13.2.3 2005/11/09 17:40:23 jlovell Exp $"
  *
  *   Server start/stop routines for the Common UNIX Printing System (CUPS).
  *
@@ -189,10 +189,6 @@ StartServer(void)
     LogMessage(L_DEBUG2, "StartServer: Adding fd %d to InputSet...", CGIPipes[0]);
     FD_SET(CGIPipes[0], InputSet);
   }
-
-#ifdef __APPLE__
-  StartSysEventMonitor();
-#endif	/* __APPLE__ */
 }
 
 
@@ -213,8 +209,6 @@ StopServer(void)
   StopBrowsing();
 
 #ifdef __APPLE__
-  StopSysEventMonitor();
-
  /* 
   * Unload Print Service quota enforcement library (X Server only) 
   */
@@ -250,6 +244,7 @@ StopServer(void)
     LogMessage(L_DEBUG2, "StopServer: Removing fd %d from InputSet...",
                CGIPipes[0]);
 
+    FD_CLR(CGIPipes[0], InputFds);
     FD_CLR(CGIPipes[0], InputSet);
 
     cupsdClosePipe(CGIPipes);
@@ -292,7 +287,7 @@ void StartSysEventMonitor(void)
 {
   int flags;
 
-  if (pipe(SysEventPipes))
+  if (cupsdOpenPipe(SysEventPipes))
   {
     LogMessage(L_EMERG, "System event monitor pipe() failed - %s!", strerror(errno));
     return;
@@ -355,16 +350,13 @@ void StopSysEventMonitor(void)
 
   if (SysEventPipes[0] >= 0)
   {
-    close(SysEventPipes[0]);
-    close(SysEventPipes[1]);
-
     LogMessage(L_DEBUG2, "StopServer: Removing fd %d from InputSet...",
 		SysEventPipes[0]);
 
+    FD_CLR(SysEventPipes[0], InputFds);
     FD_CLR(SysEventPipes[0], InputSet);
 
-    SysEventPipes[0] = -1;
-    SysEventPipes[1] = -1;
+    cupsdClosePipe(SysEventPipes);
   }
 }
 
@@ -378,6 +370,7 @@ void UpdateSysEventMonitor(void)
   cups_sysevent_t	sysevent;	/* The system event */
   printer_t		*p,		/* Printer information */
 			*next;		/* Pointer to next printer in list */
+  int			num_printers;	/* Number of printers */
 
  /*
   * Drain the event pipe...
@@ -410,7 +403,7 @@ void UpdateSysEventMonitor(void)
 
     if ((sysevent.event & SYSEVENT_WILLSLEEP))
     {
-      LogMessage(L_INFO, "System going to sleep");
+      LogMessage(L_DEBUG, "System going to sleep");
       Sleeping = 1;
       StopAllJobs();
 
@@ -420,8 +413,19 @@ void UpdateSysEventMonitor(void)
 
 	if (p->type & CUPS_PRINTER_REMOTE)
 	{
-	  LogMessage(L_INFO, "Deleting remote destination \"%s\"", p->name);
+	 /*
+	  * Deleting a printer that is part of an implicit class can also cause 
+	  * a following class to be deleted (which our 'next' may be pointing at). 
+	  * In this case reset 'next' to the head of the list...
+	  */
+    
+	  num_printers = NumPrinters;
+
+	  LogMessage(L_DEBUG, "Deleting remote destination \"%s\"", p->name);
 	  DeletePrinter(p, 0);
+
+	  if (NumPrinters != num_printers - 1)
+	    next = Printers;
 	}
 	else
 	{
@@ -435,7 +439,7 @@ void UpdateSysEventMonitor(void)
 
     if ((sysevent.event & SYSEVENT_WOKE))
     {
-      LogMessage(L_INFO, "System woke from sleep");
+      LogMessage(L_DEBUG, "System woke from sleep");
       IOAllowPowerChange(sysevent.powerKernelPort, sysevent.powerNotificationID);
       Sleeping = 0;
       CheckJobs();
@@ -616,15 +620,13 @@ static void *sysEventThreadEntry()
     CFRelease(threadData.timerRef);
   }
 
-  if (powerRLS)
+  if (threadData.sysevent.powerKernelPort)
   {
     CFRunLoopRemoveSource(CFRunLoopGetCurrent(), powerRLS, kCFRunLoopDefaultMode);
-    CFRunLoopSourceInvalidate(powerRLS);
-    CFRelease(powerRLS);
-  }
-
-  if (threadData.sysevent.powerKernelPort)
     IODeregisterForSystemPower(&powerNotifierObj);
+    IOServiceClose(threadData.sysevent.powerKernelPort);
+    IONotificationPortDestroy(powerNotifierPort);
+  }
 
   if (storeRLS)
   {
@@ -761,5 +763,5 @@ static void sysEventTimerNotifier(CFRunLoopTimerRef timer, void *context)
 #endif	/* __APPLE__ */
 
 /*
- * End of "$Id: server.c,v 1.13 2005/01/06 01:26:12 jlovell Exp $".
+ * End of "$Id: server.c,v 1.13.2.3 2005/11/09 17:40:23 jlovell Exp $".
  */
